@@ -31,6 +31,7 @@ class DummyEvent:
         self.artist = artist
         self.mouseevent = mouseevent
 
+
 # -----------------------------------------------------------------------------
 # Class to abstract the management of Figs (windows)
 #
@@ -89,7 +90,7 @@ class FigManager:
         fig=None,
         subtitle=False,
         *,
-        share_legends_regex=None
+        share_legends_regex=None,
     ):
         self.name = name
         self.parent = parent
@@ -152,8 +153,8 @@ class FigManager:
         self.key_presses = {}
 
         self.key_presses["c"] = [
-            lambda self, e: self.display_msg("No multi-core data available.", 1)
-            if self.parent.cores < 2
+            lambda self, e: self.display_msg("No multi-core POI data available.", 1)
+            if self.parent.config.cores < 2
             else self.display_msg("--dont-graph-cpu-lines on the commandline", 1)
             if not self.parent.config.plot_poi_cpu_lines
             else self.parent.graph_poi_per_cpu(use_progress_window=True),
@@ -162,8 +163,8 @@ class FigManager:
 
         self.key_presses["C"] = [
             lambda self, e: self.parent.graph_cpu_per_cpu(use_progress_window=True)
-            if self.parent.cores > 1
-            else self.display_msg("No multi-core data available.", 1),
+            if self.parent.config.has_cpu_rows
+            else self.display_msg("No multi-core CPU data available.", 1),
             "Display CPU data in a separate graph for each CPU core.",
         ]
 
@@ -226,9 +227,7 @@ class FigManager:
 
         for n in range(4):
 
-            title, _, subtitle = self.parent.ordinal_to_cartesian_map(n)[
-                "title"
-            ].partition("\n")
+            title, _, subtitle = self.parent.ordinal_to_title(n).partition("\n")
 
             self.key_presses[f"{str(n+1)}"] = [
                 lambda self, e: self.parent.graph_by_overview_ordinal(
@@ -352,7 +351,7 @@ class FigManager:
             self.msg_text_box = self.fig.text(0.5, 0.5, txt, bbox=bbox_props, **props)
 
         else:
-            self.msg_text_box.text = txt
+            self.msg_text_box._text = txt
             self.msg_text_box.set_visible(True)
 
         self.fig.canvas.draw()
@@ -389,7 +388,9 @@ class FigManager:
                         txt += f"    '{key}' : {item_text}\n\n"
 
                 txt += "#1: If the mouse pointer is over a graph, this applies to just that graph;"
-                txt += "    otherwise it applies to all the graphs in the active window."
+                txt += (
+                    "    otherwise it applies to all the graphs in the active window."
+                )
 
             elif page == 2:
                 txt = """Graph legends:
@@ -734,11 +735,7 @@ Page {page}   Version: {self.parent.config.version}    """
     # Close the window
 
     def close(self):
-        manager = self.fig.canvas.manager
-
-        # Tkinter specific code follows. If you change GUI toolkit (e.g. to
-        # QT), this will break.
-        manager.window.destroy()
+        plt.close(self.fig)
 
         # Tidy up
         self.onclose(None)
